==> haskell-hls-plugin-api-2.0.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-plugin-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.0.0.0
visibility:           public
id:                   hls-plugin-api-2.0.0.0-LgSw2LvZrUpJ7ID7iA1h02
key:                  hls-plugin-api-2.0.0.0-LgSw2LvZrUpJ7ID7iA1h02
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  89e1853837d4348bc16dbfa5916dbe15
exposed:              True
exposed-modules:
    Ide.Plugin.Config Ide.Plugin.ConfigUtils Ide.Plugin.Properties
    Ide.Plugin.RangeMap Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.0.0.0-LgSw2LvZrUpJ7ID7iA1h02
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dependent-map-0.4.0.0-9nsLLuPdKK7JpvnlvwW06g
    dependent-sum-0.7.2.0-5fTblGalXlE75UjMStPu4v
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2 ghc-9.4.8
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-graph-2.0.0.0-7VCMTFmq2mkd3hfSIH4L3
    hw-fingertree-0.1.2.1-2Pt4lQALicF1b89ZgsUV0v
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1
    lens-aeson-1.2.3-BgzfHMX9abW9bmEvP0rCoO
    lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O
    opentelemetry-0.8.0-1XYVj6L50eAG9JojJXk2JS
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-plugin-api-2.0.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-plugin-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.0.0.0
visibility:           public
id:                   hls-plugin-api-2.0.0.0-636d6FSkLCVCSM2q1qtO4N
key:                  hls-plugin-api-2.0.0.0-636d6FSkLCVCSM2q1qtO4N
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4ebc8704608ce02f5d74ecf632864cda
exposed:              True
exposed-modules:
    Ide.Plugin.Config Ide.Plugin.ConfigUtils Ide.Plugin.Properties
    Ide.Plugin.RangeMap Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.0.0.0-636d6FSkLCVCSM2q1qtO4N
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dependent-map-0.4.0.0-9nsLLuPdKK7JpvnlvwW06g
    dependent-sum-0.7.2.0-5fTblGalXlE75UjMStPu4v
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2 ghc-9.4.8
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-graph-2.0.0.0-GwXWKDEh8PIJF9SjU6liFk
    hw-fingertree-0.1.2.1-2Pt4lQALicF1b89ZgsUV0v
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1
    lens-aeson-1.2.3-BgzfHMX9abW9bmEvP0rCoO
    lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O
    opentelemetry-0.8.0-1XYVj6L50eAG9JojJXk2JS
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
